@@ -1,4 +1,4 @@
 from .cli import WPWatcherCLI
-"""Main program if called with wpwatcher/cli.py"""
+"""Main program if called with python3 -m wpwatcher"""
 if __name__ == '__main__':
     WPWatcherCLI()
\ No newline at end of file
